@@ -10,7 +10,7 @@ import sys
 
 app_name = get_app_name()
 args = get_args()
-args.remove(app_name)
+# args.remove(app_name)
 
 def main():
     if (is_name_valid(app_name)):
